CHNOPS - Wikipedia

Jump to content

# CHNOPS

15 languages

- العربية
- Català
- Čeština
- Deutsch
- Español
- Français
- 한국어
- Italiano
- Português
- Русский
- Slovenčina
- Slovenščina
- Türkçe
- 粵語
- 中文

Edit links
From Wikipedia, the free encyclopedia
Acronym of the most common elements found in biological life

Graphic representation of carbon, hydrogen, nitrogen, oxygen, phosphorus, and sulfur

CHNOPS and CHON are mnemonic acronyms for the most common elements in living organisms. "CHON" stands for carbon, hydrogen, oxygen, and nitrogen, which together make up more than 95 percent of the mass of biological systems.[1] "CHNOPS" adds phosphorus and sulfur.

## Description

[edit]

Carbon, hydrogen, nitrogen, oxygen, phosphorus, and sulfur are the six most important chemical elements whose covalent combinations make up most biological molecules on Earth.[2] All of these elements are nonmetals.

Element | Mass in plants | Mass in animals | Biological uses
--- | --- | --- | ---
Carbon | 12% | 19% | Found in carbohydrates, lipids, nucleic acids, and proteins.
Hydrogen | 10% | 10% | Found in water, carbohydrates, lipids, nucleic acids, and proteins.
Nitrogen | 1% | 4% | Found in nucleic acids, proteins, some lipids (e.g. sphingolipids) and some polysaccharides (e.g. chitin)
Oxygen | 77% | 63% | Found in water, carbohydrates, lipids, nucleic acids, and proteins.
Phosphorus | <1% | <1% | Found in lipids, nucleic acids and proteins.
Sulfur | <1% | <1% | Found in proteins and some polysaccharides.

In animals in general, the four elements—C, H, N, and O—compose about 96% of the weight, and major minerals (macrominerals) and minor minerals (also called trace elements) compose the remainder.[1]

Sulfur is contained in the amino acids cysteine and methionine.[3] Phosphorus is contained in phospholipids, a class of lipids that are a major component of all cell membranes, as they can form lipid bilayers, which keep ions, proteins, and other molecules where they are needed for cell function, and prevent them from diffusing into areas where they should not be. Phosphate groups are also an essential component of the backbone of nucleic acids (general name for DNA & RNA) and are required to form ATP – the main molecule used as energy powering the cell in all living creatures.[4]

Carbonaceous asteroids are rich in CHON elements.[5] These asteroids are the most common type and frequently collide with Earth as meteorites. Such collisions were especially common early in Earth's history, and these impactors may have been crucial in the formation of the planet's oceans.[6]

The simplest compounds to contain all of the CHON elements are isomers fulminic acid (HCNO), isofulminic acid (HONC), cyanic acid (HOCN) and isocyanic acid (HNCO), having one of each atom.[7]

## See also

[edit]
Wikimedia Commons has media related to CHNOPS.

- Abundance of the chemical elements
- Biochemistry
- Bioinorganic chemistry
- Carbon-based life
- Micronutrient – Essential elements required by organisms

## References

[edit]

1. ^ a b
   "Atoms & Life". 27 September 2009. Archived from the original on 22 January 2021. Retrieved 9 January 2021.
2. ^ Education (2010). "CHNOPS: The Six Most Abundant Elements of Life". Pearson Education. Pearson BioCoach. Archived from the original on 27 July 2017. Retrieved 10 December 2010. Most biological molecules are made from covalent combinations of six important elements, whose chemical symbols are CHNOPS. ... Although more than 25 types of elements can be found in biomolecules, six elements are most common. These are called the CHNOPS elements; the letters stand for the chemical abbreviations of carbon, hydrogen, nitrogen, oxygen, phosphorus, and sulfur.
3. ^ Brosnan JT, Brosnan ME (June 2006). "The sulfur-containing amino acids: an overview". The Journal of Nutrition. 136 (6 Suppl): 1636S – 1640S. doi:10.1093/jn/136.6.1636S. PMID 16702333. Archived from the original on 13 January 2013. Retrieved 24 January 2011.
4. ^ Campbell, Neil A.; Brad Williamson; Robin J. Heyden (2006). Biology: Exploring Life. Boston, Massachusetts: Pearson Prentice Hall. ISBN 0-13-250882-6. Archived from the original on 2 November 2014. Retrieved 24 January 2011.
5. ^ Water vs. Rocks: Resources for Earth or for Exploration? Archived 17 October 2012 at the Wayback Machine SSI-TV video archive, recorded on 30 October 2010, 66:07, four talks and Q&A given during Session 2: Extraterrestrial Prospecting of the Space Studies Institute’s Space Manufacturing 14 conference in California. Prof. Michael A'Hearn (University of Maryland) @ 7:10 in the video. The video also includes Brad Blair, Space Studies Institute, and Prof. Leslie Gertsch, University of Missouri-Rolla: Mining Concepts Development for Accessing Asteroid Resources; Mark Sonter, Asteroid Enterprises Pty Ltd Resources: Asteroids: What We Can Expect From What We Know Now; Dr. Faith Vilas, University of Arizona, Department of Astronomy and Steward Observatory, Retrieved 2011-01-07.
6. ^ Morbidelli, A.; et al. (November 2000). "Source regions and time scales for the delivery of water to Earth". Meteoritics & Planetary Science. 35 (6): 1309–1320. Bibcode:2000M&PS...35.1309M. doi:10.1111/j.1945-5100.2000.tb01518.x.
7. ^ Lattelais, M.; Pauzat, F.; Ellinger, Y.; Ceccarelli, C. (1 June 2015). "Differential adsorption of CHON isomers at interstellar grain surfaces". Astronomy and Astrophysics. 578: A62. Bibcode:2015A&A...578A..62L. doi:10.1051/0004-6361/201526044. ISSN 0004-6361.

## External links

[edit]
Look up CHON or CHNOPS in Wiktionary, the free dictionary.

- "Impact of the Biosphere on the Earth", University of Texas at Dallas

Retrieved from "https://en.wikipedia.org/w/index.php?title=CHNOPS&oldid=1307551383"
Categories:

- Astrobiology
- Biology and pharmacology of chemical elements
- Mnemonic acronyms
- Science mnemonics
- Science fiction themes
- Astrochemistry

Hidden categories:

- Webarchive template wayback links
- Articles with short description
- Short description is different from Wikidata
- Use dmy dates from April 2021
- Commons category link is on Wikidata

CHNOPS
Add topic